# LotR Isaak Treat SDK
### Contributors: Isaak Treat

## How To Install
### pip:
pip install lotr-isaaktreat==0.0.1
Url: https://pypi.org/project/lotr-isaaktreat/0.0.1/

## Usage
### ASDF

## How To Test